import React, { useCallback, useEffect } from 'react';
import { BryntumGantt } from '@bryntum/gantt-react';
import { AjaxStore, DateHelper, DomHelper, PresetManager, StringHelper, TaskTooltip, Toast} from '@bryntum/gantt';
import taskData from './taskData.json';

const GanttView =  props => {
    const {
        startDate = new Date(),
        viewPreset  = 'weekAndDayLetter',
        ganttRef,
        onSelectProject 
    } = props;

const requiredPresetIds = {
        secondAndMinute   : 1, //minutes and seconds
        minuteAndHour     : 1, //hours and minutes
        hourAndDay        : 1, //days and hours
        //dayAndWeek        : 1, //weeks and days 
        //dayAndMonth       : 1, //months and days
        dayNightShift     : 1, 
        weekAndDay        : 1, //just like dayAndWeek but with different formatting
        weekAndMonth      : 1, //months and weeks
        weekAndDayLetter  : 1, //weeks and day
        weekDateAndMonth  : 1, //months and weeks (weeks shown by first day only)
        weekNumberAndYear : 1,
        monthAndYear      : 1, //years and months
        year              : 1, //years and quarters
        manyYears         : 1  //5-years and years
    };
	// The set of available Presets is what provides the zoom levels.
    const presets = PresetManager.records.filter(p => requiredPresetIds[p.id])
	const ganttConfig = {
        startDate           : startDate,
        viewPreset          : viewPreset,
        presets             : presets,
        //visibleZoomFactor   : 10,
        barMargin           : 2,
        rowHeight           : 20,
        timeRangesFeature   : {
            showCurrentTimeLine : true
        },
        // The following features are enabled by default:
        features : {
            cellEdit      : true, //isGanttEditable
        },
        columns: [
            { 
                type: 'name', 
                text : 'Project',  
                field: 'name', 
                width: 250, 
                renderer: ({record}) => {
                    return record.isLeaf ? <span>{record.name}</span> : <b>{record.name}</b>
                }
            }
        ],
        // Custom task content, display task name on child tasks
        taskRenderer({ taskRecord }) {
            if (taskRecord.isLeaf && !taskRecord.isMilestone) {
                return StringHelper.encodeHtml(taskRecord.name);
            }
        },
        listeners : {
            cellClick: ({record} ) =>onSelectProject(record)
        },
        project:{
            project:{
                "calendar"     : "general",
                "startDate"    : startDate,
                "hoursPerDay"  : 24,
                "daysPerWeek"  : 5,
                "daysPerMonth" : 20
            },
			tasksData: taskData,
            timeRangesData: [
                {
                    "id"       : 1,
                    "name"     : "Important date",
                    "startDate": startDate,
                    "duration" : 0,
                    "durationUnit" : "d",
                    "cls"      : "b-fa b-fa-diamond"
                }
            ],
            autoLoad : true,
            // The State TrackingManager which the UndoRedo widget in the toolbar uses
            stm : {
                autoRecord : true
            }
        }
    };

 return <BryntumGantt ref={ganttRef} {...ganttConfig} />
};
export default React.memo(GanttView);